@@ -67,6 +67,7 @@ var commandCache = {}
               , "isntall" : "install"
               , "up" : "update"
               , "c" : "config"
+              , "dist-tags" : "dist-tag"
               , "info" : "view"
               , "show" : "view"
               , "find" : "search"
@@ -109,8 +110,10 @@ var commandCache = {}
               , "stars"
               , "tag"
               , "adduser"
+              , "logout"
               , "unpublish"
               , "owner"
+              , "access"
               , "deprecate"
               , "shrinkwrap"
 
@@ -131,6 +134,7 @@ var commandCache = {}
               , "prefix"
               , "bin"
               , "whoami"
+              , "dist-tag"
 
               , "test"
               , "stop"
