@@ -7,6 +7,8 @@ process.env.npm_config_loglevel = "error"
 
 var npm_config_cache = path.resolve(__dirname, "npm_cache")
 process.env.npm_config_cache = exports.npm_config_cache = npm_config_cache
+process.env.npm_config_userconfig = exports.npm_config_userconfig = path.join(__dirname, "fixtures", "config", "userconfig")
+process.env.random_env_var = "foo"
 
 var bin = exports.bin = require.resolve("../bin/npm-cli.js")
 var once = require("once")
@@ -16,7 +18,7 @@ exports.npm = function (cmd, opts, cb) {
   cmd = [bin].concat(cmd)
   opts = opts || {}
 
-  opts.env = opts.env ? opts.env : process.env
+  opts.env = opts.env || process.env
   if (!opts.env.npm_config_cache) {
     opts.env.npm_config_cache = npm_config_cache
   }
